import { useState } from "react";
import { useLocation, useNavigate } from "@tanstack/react-router";
import {
	Select,
	SelectContent,
	SelectTrigger,
	SelectValue
} from "@/components/ui/select";
import {
	Card,
	CardContent,
	CardDescription,
	CardHeader,
	CardTitle
} from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { IconBuildingStore, IconClock, IconLink } from "@tabler/icons-react";

export default function ShopSidebar({ ...props }) {
	const { pathname } = useLocation();
	const navigate = useNavigate();
	const [val, setVal] = useState(pathname ?? "/settings");

	const handleSelect = (e: string) => {
		setVal(e);
		navigate({ to: e });
	};

	return (
		<>
			<div className="p-1 md:hidden">
				<Select value={val} onValueChange={handleSelect}>
					<SelectTrigger className="h-12 sm:w-48">
						<SelectValue placeholder="Theme" />
					</SelectTrigger>
					<SelectContent></SelectContent>
				</Select>
			</div>

			<Card className="sticky h-fit top-2">
				<CardHeader>
					<CardTitle className="font-heading text-2xl">Shop Preview</CardTitle>
					<CardDescription className="text-muted-foreground">
						Update your shop details and preferences
					</CardDescription>
				</CardHeader>
				<CardContent>
					<div className="relative mb-4 aspect-square w-full overflow-hidden rounded-lg">
						<img
							alt="Shop preview"
							src="/images/placeholder.png"
							width={400}
							height={400}
							className="object-cover"
						/>
						<div className="absolute bottom-0 left-0 right-0 bg-gradient-to-t from-background/90 to-background/0 p-4">
							<Badge variant="secondary" className="mb-2">
								Status: Inactive
							</Badge>
						</div>
					</div>
					<div className="space-y-4">
						<div className="flex items-center gap-2">
							<IconBuildingStore className="h-4 w-4 text-muted-foreground" />
							<p className="text-sm text-muted-foreground">
								Complete your profile to activate your shop
							</p>
						</div>
						<div className="flex items-center gap-2">
							<IconClock className="h-4 w-4 text-muted-foreground" />
							<p className="text-sm text-muted-foreground">
								Set business hours
							</p>
						</div>
						<div className="flex items-center gap-2">
							<IconLink className="h-4 w-4 text-muted-foreground" />
							<p className="text-sm text-muted-foreground">
								Add social media links
							</p>
						</div>
					</div>
				</CardContent>
			</Card>
		</>
	);
}
